@@ -14,7 +14,7 @@ use Text::ParseWords qw( shellwords );
 # for this [AlienBase::Wrapper::Bundle]
 
 # ABSTRACT: Compiler and linker wrapper for Alien
-our $VERSION = '2.42'; # VERSION
+our $VERSION = '2.65'; # VERSION
 
 
 sub _join
@@ -79,6 +79,9 @@ sub new
       $libs   = $alien->libs;
     }
 
+    $cflags = '' unless defined $cflags;
+    $libs = '' unless defined $libs;
+
     push @cflags_I,     grep  /^-I/, shellwords $cflags;
     push @cflags_other, grep !/^-I/, shellwords $cflags;
 
@@ -322,7 +325,7 @@ Alien::Base::Wrapper - Compiler and linker wrapper for Alien
 
 =head1 VERSION
 
-version 2.42
+version 2.65
 
 =head1 SYNOPSIS
 
@@ -570,7 +573,7 @@ nick nauwelaerts (INPHOBIA)
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2011-2020 by Graham Ollis.
+This software is copyright (c) 2011-2022 by Graham Ollis.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
